# Generated by roxygen2: do not edit by hand

S3method(is_converged,default)
S3method(is_converged,solver_result)
S3method(mle_problem,default)
S3method(mle_problem,likelihood_model)
S3method(num_iterations,default)
S3method(num_iterations,solver_result)
S3method(optimization_path,mle_trace_data)
S3method(optimization_path,solver_result)
S3method(plot,mle_trace_data)
S3method(plot,solver_result)
S3method(print,mle_problem)
S3method(print,mle_trace)
S3method(print,mle_trace_data)
S3method(update,mle_problem)
export("%>>%")
export("%|%")
export(bfgs)
export(chain)
export(clear_cache)
export(compose)
export(compose_transforms)
export(coordinate_ascent)
export(fisher_scoring)
export(get_fisher)
export(get_score)
export(gradient_ascent)
export(grid_search)
export(is_converged)
export(is_mle_constraint)
export(is_mle_problem)
export(is_solver_result)
export(is_tracing)
export(lbfgsb)
export(mle_constraint)
export(mle_problem)
export(mle_trace)
export(nelder_mead)
export(newton_raphson)
export(normal_sampler)
export(num_iterations)
export(optimization_path)
export(penalty_elastic_net)
export(penalty_l1)
export(penalty_l2)
export(race)
export(random_search)
export(sim_anneal)
export(uniform_sampler)
export(unless_converged)
export(with_penalty)
export(with_restarts)
export(with_subsampling)
importFrom(algebraic.mle,mle_numerical)
importFrom(graphics,abline)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(stats,optim)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(utils,tail)
